@@ -6,7 +6,8 @@
 ;   the terms of this license.
 ;   You must not remove this notice, or any other, from this software.
 
-(ns clojure.tools.deps.alpha.script.parse
+(ns ^{:skip-wiki true}
+  clojure.tools.deps.alpha.script.parse
   (:require
     [clojure.java.io :as jio]
     [clojure.string :as str]
@@ -38,4 +39,4 @@
   "Parses a string of edn into a deps map."
   [s]
   (#'reader/canonicalize-all-syms  ;; to be removed in the future
-    (edn/read-string s)))
\ No newline at end of file
+    (edn/read-string s)))
